"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Voronoi = void 0;
var _react = _interopRequireDefault(require("react"));
var _victoryCore = require("victory-core");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const getVoronoiPath = props => {
  const {
    polygon
  } = props;
  return Array.isArray(polygon) && polygon.length ? `M ${props.polygon?.join("L")} Z` : "";
};
function evaluateProps(props) {
  /**
   * Potential evaluated props are:
   * `aria-label`
   * `id`
   * `size`
   * `style`
   * `tabIndex
   */
  const ariaLabel = _victoryCore.Helpers.evaluateProp(props.ariaLabel, props);
  const id = _victoryCore.Helpers.evaluateProp(props.id, props);
  const size = _victoryCore.Helpers.evaluateProp(props.size, props);
  const style = _victoryCore.Helpers.evaluateStyle(props.style, props);
  const tabIndex = _victoryCore.Helpers.evaluateProp(props.tabIndex, props);
  return Object.assign({}, props, {
    ariaLabel,
    id,
    size,
    style,
    tabIndex
  });
}
const defaultProps = {
  pathComponent: /*#__PURE__*/_react.default.createElement(_victoryCore.Path, null),
  circleComponent: /*#__PURE__*/_react.default.createElement(_victoryCore.Circle, null),
  clipPathComponent: /*#__PURE__*/_react.default.createElement(_victoryCore.ClipPath, null),
  groupComponent: /*#__PURE__*/_react.default.createElement("g", null),
  role: "presentation",
  shapeRendering: "auto"
};
const Voronoi = initialProps => {
  const props = evaluateProps({
    ...defaultProps,
    ...initialProps
  });
  const {
    ariaLabel,
    role,
    shapeRendering,
    className,
    events,
    transform,
    style,
    size,
    tabIndex
  } = props;
  const voronoiPath = getVoronoiPath(props);
  const sharedProps = {
    "aria-label": ariaLabel,
    className,
    role,
    shapeRendering,
    style,
    tabIndex,
    transform,
    ...events
  };
  const userProps = _victoryCore.UserProps.getSafeUserProps(props);
  if (size) {
    const circle = /*#__PURE__*/_react.default.cloneElement(props.circleComponent, {
      ...sharedProps,
      key: `${props.id}-circle-clip`,
      clipPath: `url(#${props.clipId})`,
      cx: props.x,
      cy: props.y,
      r: size
    });
    const voronoiClipPath = /*#__PURE__*/_react.default.cloneElement(props.clipPathComponent, {
      key: `${props.id}-voronoi-clip`,
      clipId: props.clipId
    }, /*#__PURE__*/_react.default.cloneElement(props.pathComponent, {
      d: voronoiPath,
      className
    }));
    return /*#__PURE__*/_react.default.cloneElement(props.groupComponent, {}, [voronoiClipPath, circle]);
  }
  return /*#__PURE__*/_react.default.cloneElement(props.pathComponent, {
    ...sharedProps,
    ...userProps,
    d: voronoiPath
  });
};
exports.Voronoi = Voronoi;